# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ui/widget_asa_loader.ui'
#
# Created by: PyQt5 UI code generator 5.11.3
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_WidgetAsaLoader(object):
    def setupUi(self, WidgetAsaLoader):
        WidgetAsaLoader.setObjectName("WidgetAsaLoader")
        WidgetAsaLoader.resize(500, 700)
        font = QtGui.QFont()
        font.setFamily("微軟正黑體")
        WidgetAsaLoader.setFont(font)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(WidgetAsaLoader)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.groupBox_serial = QtWidgets.QGroupBox(WidgetAsaLoader)
        self.groupBox_serial.setObjectName("groupBox_serial")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.groupBox_serial)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label_selecSerialPort = QtWidgets.QLabel(self.groupBox_serial)
        self.label_selecSerialPort.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.label_selecSerialPort.setBaseSize(QtCore.QSize(0, 0))
        self.label_selecSerialPort.setObjectName("label_selecSerialPort")
        self.horizontalLayout_2.addWidget(self.label_selecSerialPort)
        self.comboBox_selectPort = QtWidgets.QComboBox(self.groupBox_serial)
        self.comboBox_selectPort.setObjectName("comboBox_selectPort")
        self.horizontalLayout_2.addWidget(self.comboBox_selectPort)
        self.pushButton_updatePortList = QtWidgets.QPushButton(self.groupBox_serial)
        self.pushButton_updatePortList.setObjectName("pushButton_updatePortList")
        self.horizontalLayout_2.addWidget(self.pushButton_updatePortList)
        self.verticalLayout_3.addWidget(self.groupBox_serial)
        self.groupBox_basicFuns = QtWidgets.QGroupBox(WidgetAsaLoader)
        self.groupBox_basicFuns.setObjectName("groupBox_basicFuns")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox_basicFuns)
        self.gridLayout.setObjectName("gridLayout")
        self.pushButton_selectFile = QtWidgets.QPushButton(self.groupBox_basicFuns)
        self.pushButton_selectFile.setObjectName("pushButton_selectFile")
        self.gridLayout.addWidget(self.pushButton_selectFile, 0, 1, 1, 1)
        self.lineEdit_selectFile = QtWidgets.QLineEdit(self.groupBox_basicFuns)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        self.lineEdit_selectFile.setFont(font)
        self.lineEdit_selectFile.setObjectName("lineEdit_selectFile")
        self.gridLayout.addWidget(self.lineEdit_selectFile, 0, 0, 1, 1)
        self.label_steps = QtWidgets.QLabel(self.groupBox_basicFuns)
        font = QtGui.QFont()
        font.setFamily("微軟正黑體")
        self.label_steps.setFont(font)
        self.label_steps.setObjectName("label_steps")
        self.gridLayout.addWidget(self.label_steps, 2, 0, 1, 3)
        self.pushButton_startProg = QtWidgets.QPushButton(self.groupBox_basicFuns)
        self.pushButton_startProg.setObjectName("pushButton_startProg")
        self.gridLayout.addWidget(self.pushButton_startProg, 1, 0, 1, 1)
        self.pushButton_stopProg = QtWidgets.QPushButton(self.groupBox_basicFuns)
        self.pushButton_stopProg.setObjectName("pushButton_stopProg")
        self.gridLayout.addWidget(self.pushButton_stopProg, 1, 1, 1, 1)
        self.verticalLayout_3.addWidget(self.groupBox_basicFuns)
        self.groupBox_specialTools = QtWidgets.QGroupBox(WidgetAsaLoader)
        self.groupBox_specialTools.setObjectName("groupBox_specialTools")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.groupBox_specialTools)
        self.verticalLayout.setObjectName("verticalLayout")
        self.pushButton_progStk500 = QtWidgets.QPushButton(self.groupBox_specialTools)
        self.pushButton_progStk500.setObjectName("pushButton_progStk500")
        self.verticalLayout.addWidget(self.pushButton_progStk500)
        self.verticalLayout_3.addWidget(self.groupBox_specialTools)
        self.groupBox = QtWidgets.QGroupBox(WidgetAsaLoader)
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.progressBar = QtWidgets.QProgressBar(self.groupBox)
        self.progressBar.setProperty("value", 0)
        self.progressBar.setObjectName("progressBar")
        self.verticalLayout_2.addWidget(self.progressBar)
        self.formLayout = QtWidgets.QFormLayout()
        self.formLayout.setObjectName("formLayout")
        self.label_statusTitle = QtWidgets.QLabel(self.groupBox)
        self.label_statusTitle.setObjectName("label_statusTitle")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_statusTitle)
        self.label_programSizeTitle = QtWidgets.QLabel(self.groupBox)
        self.label_programSizeTitle.setObjectName("label_programSizeTitle")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_programSizeTitle)
        self.label_programSizeContent = QtWidgets.QLabel(self.groupBox)
        self.label_programSizeContent.setObjectName("label_programSizeContent")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.label_programSizeContent)
        self.label_etcTitle = QtWidgets.QLabel(self.groupBox)
        self.label_etcTitle.setObjectName("label_etcTitle")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_etcTitle)
        self.label_etcContent = QtWidgets.QLabel(self.groupBox)
        self.label_etcContent.setObjectName("label_etcContent")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.label_etcContent)
        self.label_statusContent = QtWidgets.QLabel(self.groupBox)
        self.label_statusContent.setObjectName("label_statusContent")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.label_statusContent)
        self.verticalLayout_2.addLayout(self.formLayout)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem)
        self.verticalLayout_3.addWidget(self.groupBox)

        self.retranslateUi(WidgetAsaLoader)
        QtCore.QMetaObject.connectSlotsByName(WidgetAsaLoader)

    def retranslateUi(self, WidgetAsaLoader):
        _translate = QtCore.QCoreApplication.translate
        self.groupBox_serial.setTitle(_translate("WidgetAsaLoader", "串列埠設定"))
        self.label_selecSerialPort.setText(_translate("WidgetAsaLoader", "選擇串列埠："))
        self.pushButton_updatePortList.setText(_translate("WidgetAsaLoader", "更新串列埠"))
        self.groupBox_basicFuns.setTitle(_translate("WidgetAsaLoader", "燒錄一般應用程式"))
        self.pushButton_selectFile.setText(_translate("WidgetAsaLoader", "選擇檔案"))
        self.label_steps.setText(_translate("WidgetAsaLoader", "<html><head/><body><p>1. 用USB線將ASA_M128與電腦接上。</p><p>2. 將ASA_M128指撥開關撥到&quot;prog&quot;，並按下reset按鈕。</p><p>3. 選擇ASA_M128連接到之串列埠。</p><p>4. 點選選擇檔案，並選取欲燒錄之檔案。</p><p>5. 點選開始燒錄。</p><p>6. 等待下方進度條跑到100%即完成燒錄。</p></body></html>"))
        self.pushButton_startProg.setText(_translate("WidgetAsaLoader", "開始燒錄"))
        self.pushButton_stopProg.setText(_translate("WidgetAsaLoader", "強制終止"))
        self.groupBox_specialTools.setTitle(_translate("WidgetAsaLoader", "燒錄特殊功能應用程式"))
        self.pushButton_progStk500.setText(_translate("WidgetAsaLoader", "燒錄 \"M128_STK500\"  (可將ASA_M128轉變為STK500裝置使用)"))
        self.groupBox.setTitle(_translate("WidgetAsaLoader", "燒錄狀態"))
        self.label_statusTitle.setText(_translate("WidgetAsaLoader", "當前狀態："))
        self.label_programSizeTitle.setText(_translate("WidgetAsaLoader", "程式大小："))
        self.label_programSizeContent.setText(_translate("WidgetAsaLoader", "-"))
        self.label_etcTitle.setText(_translate("WidgetAsaLoader", "預估花費時間："))
        self.label_etcContent.setText(_translate("WidgetAsaLoader", "-"))
        self.label_statusContent.setText(_translate("WidgetAsaLoader", "等待燒錄"))

